@@ -1,6 +1,6 @@
 from requests.exceptions import ConnectionError, ReadTimeout
 from rlockertools.exceptions import BadRequestError, TimeoutReachedForLockingResource
-from rlockertools.utils import prettify_output
+from rlockertools.utils import prettify_output, parse_queue_data
 import requests
 import datetime
 import json
@@ -170,7 +170,7 @@ class ResourceLocker:
         req = requests.get(final_endpoint, headers=self.headers)
         if req.status_code == 200:
             # Check for data dictionary args to override if needed:
-            data_section = json.loads(req.json().get('data'))
+            data_section = parse_queue_data(req.json().get('data'))
             if datakwargs:
                 for k, v in datakwargs.items():
                     data_section[k] = v
